Aerial Library
==============

Python library for the robo4you Aerial Junior Challenge.

Enables simple, intuitive interaction with the bitcraze Crazyflie 2.1 drone.


Usage
-----
```py
from aerial_library import Drone, FlowDeck

with Drone("E7E7E7E7E7", FlowDeck) as drone:
    drone.takeoff(1.0)
    drone.move_forward(0.5)
```

See the documentation of `Drone` and `Actions` for details.


Documentation
-------------
You can find a **user guide** as well as the **API documentation** on our website:

https://aerial-challenge.org/downloads
